summaryrefslogtreecommitdiff
path: root/deps/v8/src/compiler/backend/ia32/instruction-selector-ia32.cc
diff options
context:
space:
mode:
Diffstat (limited to 'deps/v8/src/compiler/backend/ia32/instruction-selector-ia32.cc')
-rw-r--r--deps/v8/src/compiler/backend/ia32/instruction-selector-ia32.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/deps/v8/src/compiler/backend/ia32/instruction-selector-ia32.cc b/deps/v8/src/compiler/backend/ia32/instruction-selector-ia32.cc
index 1e241a8ae9..2740412383 100644
--- a/deps/v8/src/compiler/backend/ia32/instruction-selector-ia32.cc
+++ b/deps/v8/src/compiler/backend/ia32/instruction-selector-ia32.cc
@@ -72,10 +72,11 @@ class IA32OperandGenerator final : public OperandGenerator {
// really have to this here, then we need to find a way to put this
// information on the HeapConstant node already.
#if 0
// Constants in new space cannot be used as immediates in V8 because
// the GC does not scan code objects when collecting the new generation.
Handle<HeapObject> value = HeapConstantOf(node->op());
- return !Heap::InNewSpace(*value);
+ return !Heap::InYoungGeneration(*value);
#else
return false;
#endif
@@ -72,10 +72,11 @@ class IA32OperandGenerator final : public OperandGenerator {
// information on the HeapConstant node already.
#if 0
- // Constants in new space cannot be used as immediates in V8 because
- // the GC does not scan code objects when collecting the new generation.
+ // Constants in young generation cannot be used as immediates in V8
+ // because the GC does not scan code objects when collecting the young
+ // generation.
Handle<HeapObject> value = HeapConstantOf(node->op());